import { FormGroup } from '@angular/forms';
import { Subject } from 'rxjs/Subject';
export declare class FormElement {
    inputId: string;
    type: string;
    label: string;
    subType?: string;
    required?: boolean;
    minLength?: number;
    maxLength?: number;
    regex?: string;
    helpText?: string;
    errorText?: string;
    options?: ElementOption[];
    optionGroups?: ElementOptionGroup[];
    optionObjects?: {}[];
    formArrayControls?: FormElement[];
    formArraySingularName?: string;
    config?: FormElementConfig;
    accessibilityConfig?: FormElementAccessibilityConfig;
    stylesConfig?: FormElementStyleConfig;
    formArrayValue?: Subject<any[]>;
    constructor(data: {
        inputId: string;
        type: string;
        label: string;
        subType?: string;
        required?: boolean;
        minLength?: number;
        maxLength?: number;
        regex?: string;
        helpText?: string;
        errorText?: string;
        options?: ElementOption[];
        optionGroups?: ElementOptionGroup[];
        config?: FormElementConfig;
        accessibilityConfig?: FormElementAccessibilityConfig;
        stylesConfig?: FormElementStyleConfig;
        optionObjects?: {}[];
        formArrayControls?: FormElement[];
        formArraySingularName?: string;
        formArrayValue?: Subject<any[]>;
    });
    setArrayValues: (data: any[]) => void;
    setConfig: (property: string, value: any) => this;
    getConfig: (property: string) => any;
    setProperty: (property: string, value: any) => this;
    setAccessibility: (property: string, value: any) => this;
    setStyle: (property: string, value: any) => this;
    getStyle: (property: string) => any;
    getAccessibility: (property: string) => any;
    getTestId: (optionValue?: string) => string;
}
export declare class ComponentValue {
    inputId: string;
    value: any;
    isValid: boolean;
    constructor(data: {
        inputId: string;
        value: any;
        isValid: boolean;
    });
}
export declare class ElementOption {
    value: string;
    display: string;
    constructor(data: {
        value: string;
        display: string;
    });
}
export declare class ElementOptionGroup {
    groupName: string;
    options: ElementOption[];
    constructor(data: {
        groupName: string;
        options: ElementOption[];
    });
}
export declare class ObjectGroup {
    groupName: string;
    objects: {}[];
    constructor(data: {
        groupName: string;
        objects: {}[];
    });
}
/**
 * FormDetails object for unwrapped forms
 * @TODO - refer to this as a loose form? Does that make more sense? Who knows! 🙈
 */
export declare class FormDetails {
    elements: {
        inputId: string;
        element: FormElement;
    }[];
    formGroup: FormGroup;
    constructor(data?: {
        elements: {
            inputId: string;
            element: FormElement;
        }[];
        formGroup: FormGroup;
    });
    get: (inputId: string) => FormElement;
    setConfig: (inputId: string, propertyName: string, value: string) => this;
    setStyle: (inputId: string, propertyName: string, value: string) => this;
    setGlobalStyle: (propertyName: string, value: string) => this;
    setAccessibility: (inputId: string, propertyName: string, value: string) => this;
}
export interface FormElementOptions {
    inputId?: string;
    required?: boolean;
    minLength?: number;
    maxLength?: number;
    regex?: string;
    helpText?: string;
    errorText?: string;
    options?: ElementOption[];
    optionGroups?: ElementOptionGroup[];
    optionObjects?: {}[];
    formArrayControls?: FormElement[];
    formArraySingularName?: string;
}
export declare class Elements {
    static Text: string;
    static Select: string;
    static Checkbox: string;
    static Radio: string;
    static Password: string;
    static Datepicker: string;
    static Range: string;
    static Textarea: string;
    static ObjectSelector: string;
    static FormArray: string;
}
export declare class Properties {
    static InputId: string;
    static Required: string;
    static MinLength: string;
    static MaxLength: string;
    static Regex: string;
    static HelpText: string;
    static ErrorText: string;
    static Options: string;
    static OptionGroups: string;
}
export interface FormElementConfig {
    requiredMarker?: string;
    readOnly?: boolean;
    objectDisplayProperty?: string;
    objectGroupProperty?: string;
    shouldGroupObjects?: string;
}
export declare class Config {
    static RequiredMarker: string;
    static ReadOnly: string;
    static ObjectDisplayProperty: string;
    static ObjectGroupProperty: string;
    static ShouldGroupObjects: string;
}
export interface FormElementAccessibilityConfig {
    ariaLabel?: string;
    ariaDescribedBy?: string;
    ariaLabelledBy?: string;
    ariaReadOnly?: boolean;
}
export declare class Accessibility {
    static AriaLabel: string;
    static AriaDescribedBy: string;
    static AriaLabelledBy: string;
    static AriaReadOnly: string;
}
export interface FormElementStyleConfig {
    wrapperCssClass?: string;
    groupLabelCssClass?: string;
    elementLabelCssClass?: string;
    elementInputCssClass?: string;
    fieldsetCssClass?: string;
    legendCssClass?: string;
    optionLabelCssClass?: string;
}
export declare class Styles {
    static ElementWrapper: string;
    static GroupLabel: string;
    static ElementLabel: string;
    static ElementInput: string;
    static Fieldset: string;
    static Legend: string;
    static OptionLabel: string;
}
export interface LabelConfig {
    inputFocussed?: boolean;
    inputHasValue?: boolean;
    requiredMarker?: string;
    modifier?: string;
    elementData: FormElement;
    inputIsValid?: boolean;
    inputIsInvalid?: boolean;
    testId: string;
}
